#
# spec file for package plib
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           plib
Version:        1.8.5+svn.2173
Release:        7.2
Summary:        A collection of game libraries
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
URL:            http://plib.sourceforge.net/
Source:         %{name}-%{version}.tar.xz
Source99:       %{name}-rpmlintrc
# PATCH-FEATURE-UPSTREAM -- https://sourceforge.net/p/plib/bugs/40/
Patch0:         plib-1.8.5-shared.patch
# PATCH-FIX-UPSTREAM -- https://sourceforge.net/p/plib/bugs/49/
Patch1:         plib-1.8.5-strncat.patch
# PATCH-FIX-UPSTREAM -- https://sourceforge.net/p/plib/bugs/50/
Patch2:         plib-1.8.5-CVE-2011-4620.patch
# PATCH-FIX-UPSTREAM -- https://sourceforge.net/p/plib/bugs/51/
Patch3:         plib-1.8.5-CVE-2012-4552.patch
# PATCH-FIX-UPSTREAM -- https://sourceforge.net/p/plib/bugs/55/
Patch4:         plib-1.8.5-CVE-2021-38714.patch
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(x11)

%description
Plib contains a selection of libraries that can be helpful for 3D game
programming.

%package -n libplib0
Summary:        A collection of game libraries
Group:          System/Libraries
Obsoletes:      plib < %{version}-%{release}
Provides:       plib = %{version}-%{release}

%description -n libplib0
Plib contains a selection of libraries that can be helpful for 3D game
programming. It contains the following libraries:
* JS  - A Joystick interface
* PUI - A simple GUI built on top of OpenGL
* SG  - Some Standard Geometry functions
* SL  - A Games-oriented Sound Library
* SSG - A Simple Scene Graph API built on top of OpenGL

%package devel
Summary:        Development files for PLIB, a collection of game libraries
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libplib0 = %{version}
Requires:       pkgconfig(gl)

%description devel
Plib contains a selection of libraries that can be helpful for 3D game
programming. It contains the following libraries:
* JS - A Joystick interface.
* PUI - A simple GUI built on top of OpenGL
* SG - Some Standard Geometry functions
* SL - A Games-oriented Sound Library
* SSG - A Simple Scene Graph API built on top of OpenGL

%prep
%autosetup -p0

%build
autoreconf -fiv
export CXXFLAGS="%{optflags} -fno-strict-aliasing"
%configure --disable-static
make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post   -n libplib0 -p /sbin/ldconfig
%postun -n libplib0 -p /sbin/ldconfig

%files -n libplib0
%license AUTHORS COPYING
%doc ChangeLog KNOWN_BUGS
%{_libdir}/libplib*.so.*

%files devel
%doc NOTICE README README.GLUT
%{_includedir}/plib
%{_libdir}/libplib*.so

%changelog
* Thu Feb 29 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Sun Oct 31 2021 ldreier@vodafonemail.de
- add plib-1.8.5-CVE-2021-38714.patch from Anton Gladky to fix
  original security issue (boo#1189887)
* Tue Aug 31 2021 Luigi Baldoni <aloisio@gmx.com>
- Disable libssg and libssgaux build to fix (boo#1189887)
* Thu Nov 28 2019 Luigi Baldoni <aloisio@gmx.com>
- Fix factory build
- Spec cleanup
* Wed Nov 29 2017 crrodriguez@opensuse.org
- Require just pkgconfig(gl) for build and -devel package.
* Mon Nov 14 2016 jengelh@inai.de
- Replace questionable Mesa binary require for devel package
* Thu Sep  1 2016 rpm@fthiessen.de
- Update to current svn version 1.8.5+svn.2173
  * Removed upstream fixed patches:
    plib-1.8.5-commit2136-segfault.patch,
    plib-1.8.5-commit2139-slider.patch,
    plib-1.8.5-commit2140-slider.patch and
    plib-1.8.5-commit2154-segfault.patch
  * Removed plib-1.8.5-intptr_t.patch
- Reported patches upstream (even if upstream is orphaned)
* Sat Jul 30 2016 jengelh@inai.de
- Implement shared library packaging guideline
* Tue Apr 23 2013 joop.boonen@opensuse.org
- Added missing BuildRequires for openSUSE > 12.3
* Sun Nov  4 2012 reddwarf@opensuse.org
- Add plib-1.8.5-CVE-2011-4620.patch (bnc#738207) and
  plib-1.8.5-CVE-2012-4552.patch (bnc#787305)
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Fri Dec 30 2011 brehmt@gmail.com
- Applied patches from plib SVN
  * Fixed segfault in puInput when pasting empty buffer
  * Fixed heap corruption when removing puInputBase objects
  * Fixed various puSlider issues
* Sun Nov 27 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
* Sun Nov 27 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Sat Jul  2 2011 jengelh@medozas.de
- Use %%_smp_mflags for parallel building
- Strip %%clean section (not needed on BS)
- Remove duplicated changelog
* Fri Jan  9 2009 crrodriguez@suse.de
- remove static libraries and "la" files
* Tue Mar 11 2008 prusnak@suse.cz
- updated to 1.8.5
  * removed several widgets from pui/, which were declared
    obsolete since a long time. Most of them are now available
    in puAux/
  * several fixes and improvements to puAuxList
  * puInputText scrolling fixed
  * Improved DirectX loader
  * Check ownership before deleting in ssgSimpleList
  * Fixed netSocket
  * Fixed mem leak in ssgVertSplitter
  * Fixed pw window sizes on win32
  * Added pview ssg-example
  * Fix clock delta in first call
  * Made colour of listbox changable
  * Fixed text with negative coordinates
  * Fixed misc bugs in puAuxLargeInput
  * Allow the user to activate a widget with custom mouse button
  * Made material loading from wavefront models more robust
  * Handle linux joysticks with a lot of axes
  * Avoid specular anomalies in 3ds files
  * Added a demo for ssgaShapes
  * Fixed the diameter of ssgaSphere
  * Fixed inability to add colour to the ssgaTeapot
  * Remove scale dep in ssgaFire
- fixed strncat usage (strncat.patch)
- dropped obsolete patches:
  * extraqual.diff (included in update)
  * joystick.diff (included in update)
* Thu Jan 10 2008 lmichnovic@suse.cz
- added glibc-devel, xorg-x11-devel as Requires
* Fri Jan  4 2008 lmichnovic@suse.cz
- fixed deprecated run_ldconfig macro
- no need to use %%suse_update_config when autotools are called
  anyway (Other dists get chocked in BuildService.)
- no need to pack files NEWS and INSTALL
- compiling with no-strict-aliasing
* Wed May 23 2007 prusnak@suse.cz
- move devel files to plib-devel subpackage
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Oct 20 2005 mmj@suse.de
- remove extra qualification
* Fri Feb 25 2005 ro@suse.de
- fix filelist (packing complete /usr/lib is not possible)
* Wed Feb 23 2005 mjancar@suse.cz
- build shared libraries (needed by torcs)
* Wed Feb  2 2005 mjancar@suse.cz
- update to 1.8.4 (needed by FlightGear)
* Fri Aug 13 2004 mjancar@suse.cz
- update to 1.8.3
* Sat Jan 10 2004 adrian@suse.de
- add %%defattr
* Mon Oct 13 2003 ro@suse.de
- remove explicit requires for mesa
* Thu Jul 31 2003 mjancar@suse.cz
- use %%run_ldconfig
* Tue Dec 10 2002 prehak@suse.cz
- fixed brace-enclosed initialization (due to gcc-3.3)
* Thu Oct 24 2002 prehak@suse.cz
- updated to version 1.6.0
* Wed Aug 21 2002 nadvornik@suse.cz
- use RPM_OPT_FLAGS instead of -O6
* Thu Jan 10 2002 rvasice@suse.cz
- use %%{_libdir}
* Fri Nov  9 2001 rvasice@suse.cz
- fix to compile with new automake
* Thu Nov  8 2001 ro@suse.de
- use mesa-devel-packages in neededforbuild
* Thu Jul 26 2001 rvasice@suse.cz
- update to version 1.4.2
* Fri Jul 13 2001 rvasice@suse.cz
- update to version 1.4.1
* Mon Jun  4 2001 rvasice@suse.cz
- spec file cleanup
- bzip2 sources
* Thu Mar 15 2001 ro@suse.de
- changed neededforbuild <mesaglu> to <xf86glu>
- changed neededforbuild <mesaglu-devel> to <xf86glu-devel>
* Tue Mar 13 2001 ro@suse.de
- added mesaglut
* Fri Mar  9 2001 ro@suse.de
- added mesaglu
* Wed Mar  7 2001 ro@suse.de
- changed neededforbuild <mesadev> to <mesa-devel>
- added xf86 to neededforbuild
* Fri Feb  9 2001 ro@suse.de
- include float.h in sg.h
* Mon Aug  7 2000 smid@suse.cz
- upgrade to 1.2.0
* Mon May 22 2000 smid@suse.cz
- mesadev added to neededforbuild
* Thu May  4 2000 smid@suse.cz
- upgrade to 1.1.11
* Fri Apr 21 2000 smid@suse.cz
- buildroot added
* Wed Feb 16 2000 grimmer@suse.de
- added URL to spec file
- use full URL to source package
- use version macro
* Tue Dec 28 1999 sndirsch@suse.de
- updated to version 1.0.20
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Wed Aug 18 1999 sndirsch@suse.de
- update to version 1.0.16
* Wed Jul  7 1999 grimmer@suse.de
- initial package created (Version 1.0.12)
